@@ -32,6 +32,7 @@ import org.opengis.referencing.ReferenceIdentifier;
 import org.opengis.referencing.crs.CoordinateReferenceSystem;
 import org.opengis.referencing.operation.TransformException;
 
+import java.awt.geom.Point2D;
 import java.util.Arrays;
 import java.util.Set;
 
@@ -105,6 +106,12 @@ public class RasterAccessors
         return RasterUtils.getWorldCornerCoordinates(raster, colX, rowY).getY();
     }
 
+    public static Geometry getWorldCoord(GridCoverage2D raster, int colX, int rowY) throws TransformException {
+        Point2D worldCoords = RasterUtils.getWorldCornerCoordinates(raster, colX, rowY);
+        Geometry point = new GeometryFactory().createPoint(new Coordinate(worldCoords.getX(), worldCoords.getY()));
+        return point;
+    }
+
     public static String getGeoReference(GridCoverage2D raster) {
         return getGeoReference(raster, "GDAL");
     }
@@ -127,6 +134,69 @@ public class RasterAccessors
         }
     }
 
+
+    public static double[] getGeoTransform(GridCoverage2D raster) throws FactoryException {
+        // size of a pixel along the transformed i axis
+        double magnitudeI;
+
+        // size of a pixel along the transformed j axis
+        double magnitudeJ;
+
+        // angle by which the raster is rotated (Radians positive clockwise)
+        double thetaI;
+
+        // angle from transformed i axis to transformed j axis (Radians positive counter-clockwise)
+        double thetaIJ;
+
+        double[] metadata = metadata(raster);
+
+        // x ordinate of the upper-left corner of the upper-left pixel
+        double offsetX = metadata[0];
+
+        // y ordinate of the upper-left corner of the upper-left pixel
+        double offsetY = metadata[1];
+
+        double scaleX = metadata[4];
+        double scaleY =  metadata[5];
+        double skewX = metadata[6];
+        double skewY = metadata[7];
+
+        // pixel size in i direction - west-east
+        magnitudeI = Math.sqrt(scaleX * scaleX + skewY * skewY);
+
+        // pixel size in j direction - north-south
+        magnitudeJ = Math.sqrt(scaleY * scaleY + skewX * skewX);
+
+        // Rotation
+        thetaI = Math.acos(scaleX / magnitudeI);
+        double thetaTest = Math.acos(skewY / magnitudeI);
+        if (thetaTest < Math.PI / 2) {
+            thetaI = -thetaI;
+        }
+
+        // Angular separation
+        thetaIJ = Math.acos((((scaleX * skewX) + (skewY * scaleY)) / (magnitudeI * magnitudeJ)));
+        thetaTest = Math.acos(((-skewY * skewX) + (scaleX * scaleY)) / (magnitudeI * magnitudeJ));
+        if (thetaTest > Math.PI / 2) {
+            thetaIJ = -thetaIJ;
+        }
+
+        double[] result = new double[6];
+        result[0] = magnitudeI;
+        result[1] = magnitudeJ;
+        result[2] = thetaI;
+        result[3] = thetaIJ;
+        result[4] = offsetX;
+        result[5] = offsetY;
+
+        return result;
+    }
+
+    public static double getRotation(GridCoverage2D raster) throws FactoryException {
+        double rotation = getGeoTransform(raster)[2];
+        return rotation;
+    }
+
     public static Geometry getGridCoord(GridCoverage2D raster, double x, double y) throws TransformException {
         int[] coords = RasterUtils.getGridCoordinatesFromWorld(raster, x, y);
         coords = Arrays.stream(coords).map(number -> number + 1).toArray();
