@@ -516,7 +516,7 @@ public class GeomUtils {
         return DiscreteFrechetDistance.distance(g1, g2);
     }
 
-    public static Double getHausdorffDistance(Geometry g1, Geometry g2, double densityFrac) throws Exception {
+    public static Double getHausdorffDistance(Geometry g1, Geometry g2, double densityFrac) {
         if (g1.isEmpty() || g2.isEmpty()) return 0.0;
         DiscreteHausdorffDistance hausdorffDistanceObj = new DiscreteHausdorffDistance(g1, g2);
         if (densityFrac != -1) {
