@@ -20,6 +20,7 @@ package org.apache.sedona.common.utils;
 
 import com.sun.media.imageioimpl.common.BogusColorSpace;
 import org.apache.commons.lang3.tuple.Pair;
+import org.apache.commons.math3.stat.descriptive.rank.Median;
 import org.apache.sedona.common.Functions;
 import org.apache.sedona.common.FunctionsGeoTools;
 import org.apache.sedona.common.raster.RasterAccessors;
@@ -31,6 +32,7 @@ import org.geotools.coverage.TypeMap;
 import org.geotools.coverage.grid.GridCoordinates2D;
 import org.geotools.coverage.grid.GridCoverage2D;
 import org.geotools.coverage.grid.GridCoverageFactory;
+import org.geotools.coverage.grid.GridEnvelope2D;
 import org.geotools.coverage.grid.GridGeometry2D;
 import org.geotools.geometry.DirectPosition2D;
 import org.geotools.referencing.crs.DefaultEngineeringCRS;
@@ -38,6 +40,7 @@ import org.geotools.referencing.operation.transform.AffineTransform2D;
 import org.geotools.util.ClassChanger;
 import org.geotools.util.NumberRange;
 import org.locationtech.jts.geom.Geometry;
+import org.opengis.coverage.grid.GridEnvelope;
 import org.opengis.geometry.DirectPosition;
 import org.opengis.metadata.spatial.PixelOrientation;
 import org.opengis.referencing.FactoryException;
@@ -59,6 +62,7 @@ import java.awt.image.ComponentColorModel;
 import java.awt.image.DataBuffer;
 import java.awt.image.Raster;
 import java.awt.image.RenderedImage;
+import java.awt.image.SampleModel;
 import java.awt.image.WritableRaster;
 import java.util.*;
 
@@ -453,10 +457,13 @@ public class RasterUtils {
         // to the raster CRS.
         // Note that:
         // In Sedona vector, we do not perform implicit CRS transform. Everything must be done explicitly via ST_Transform
-        // In Sedona raster, we do implicit CRS transform if the geometry has a SRID and the raster has a CRS
-        if (targetCRS != null && !(targetCRS instanceof DefaultEngineeringCRS) && geomSRID > 0) {
+        // In Sedona raster, we do implicit CRS transform if the raster has a CRS. If the the SRID of the geometry is 0, we assume it is 4326.
+        if (geomSRID == 0) {
+            geomSRID = 4326;
+        }
+        if (targetCRS != null && !(targetCRS instanceof DefaultEngineeringCRS)) {
             try {
-                geometry = FunctionsGeoTools.transformToGivenTarget(geometry, null, targetCRS, true);
+                geometry = FunctionsGeoTools.transformToGivenTarget(geometry, "epsg:" + geomSRID, targetCRS, true);
             } catch (FactoryException | TransformException e) {
                 throw new RuntimeException("Cannot transform CRS of query window", e);
             }
@@ -642,4 +649,164 @@ public class RasterUtils {
                     "Second raster having width of %d and height of %d", width1, height1, width2, height2));
         }
     }
+
+    /**
+     * Shift the rendered image inside the grid coverage to have a zero origin. This won't alter the cell values of
+     * the raster, but will shift the affine transformation to cancel with the origin shift.
+     * @param raster The raster to shift
+     * @param noDataValue The no data value to use for the new raster
+     * @return A new grid coverage with the same cell values but its rendered image has a zero origin
+     */
+    public static GridCoverage2D shiftRasterToZeroOrigin(GridCoverage2D raster, Double noDataValue) {
+        RenderedImage image = raster.getRenderedImage();
+        SampleModel sampleModel = image.getSampleModel();
+        int width = image.getWidth();
+        int height = image.getHeight();
+        int minX = image.getMinX();
+        int minY = image.getMinY();
+        if (minX != 0 || minY != 0) {
+            GridGeometry2D gridGeometry = raster.getGridGeometry();
+            AffineTransform2D transform = (AffineTransform2D) gridGeometry.getGridToCRS2D();
+            AffineTransform2D newAffine = RasterUtils.translateAffineTransform(transform, minX, minY);
+            GridEnvelope newGridEnvelope = new GridEnvelope2D(0, 0, width, height);
+            GridGeometry2D newGridGeometry = new GridGeometry2D(newGridEnvelope, newAffine, gridGeometry.getCoordinateReferenceSystem());
+            WritableRaster wr = RasterFactory.createBandedRaster(sampleModel.getDataType(), image.getWidth(), image.getHeight(), sampleModel.getNumBands(), null);
+            wr.setRect(-minX, -minY, RasterUtils.getRaster(image));
+            return RasterUtils.clone(wr, newGridGeometry, raster.getSampleDimensions(), raster, noDataValue, true);
+        } else {
+            return RasterUtils.clone(raster.getRenderedImage(), raster.getGridGeometry(), raster.getSampleDimensions(), raster, noDataValue, true);
+        }
+    }
+
+    /**
+     * Retrieves a List<Double> of neighboring pixel values excluding noDataValue neighbors
+     *
+     * @param x grid coordinate
+     * @param y grid coordinate
+     * @param band Band index of raster
+     * @param raster
+     * @param noDataValue
+     * @return
+     */
+    public static List<Double> getNeighboringPixels(int x, int y, int band, Raster raster, Double noDataValue) {
+        List<Double> neighbors = new ArrayList<>();
+        int width = raster.getWidth();
+        int height = raster.getHeight();
+
+        for (int dx = -1; dx <= 1; dx++) {
+            for (int dy = -1; dy <= 1; dy++) {
+                int nx = x + dx;
+                int ny = y + dy;
+
+                if (nx >= 0 && nx < width && ny >= 0 && ny < height && !(dx == 0 && dy == 0)) {
+                    double value = raster.getSampleDouble(nx, ny, band); // Now checks the specified band
+                    if (value != noDataValue) {
+                        neighbors.add(value);
+                    }
+                }
+            }
+        }
+        return neighbors;
+    }
+
+
+    /**
+     * Replaces noDataValue pixels in each band with mean of neighboring pixel values
+     *
+     * @param raster
+     * @return A new grid coverage with noDataValues pixels replaced
+     */
+    public static GridCoverage2D replaceNoDataValues(GridCoverage2D raster) {
+        Raster rasterData = raster.getRenderedImage().getData();
+        WritableRaster writableRaster = rasterData.createCompatibleWritableRaster();
+
+        Median medianCalculator = new Median();
+
+        // Iterate over each band
+        for (int band = 0; band < raster.getNumSampleDimensions(); band++) {
+            GridSampleDimension sampleDimension = raster.getSampleDimension(band);
+            double noDataValue = RasterUtils.getNoDataValue(sampleDimension);
+
+            // Replace no data values with the median of neighboring pixels for each band
+            for (int y = 0; y < rasterData.getHeight(); y++) {
+                for (int x = 0; x < rasterData.getWidth(); x++) {
+                    double originalValue = rasterData.getSampleDouble(x, y, band);
+                    if (originalValue == noDataValue) {
+                        List<Double> neighbors = RasterUtils.getNeighboringPixels(x, y, band, rasterData, noDataValue);
+                        double[] neighborArray = neighbors.stream().mapToDouble(Double::doubleValue).toArray();
+                        double medianValue = neighborArray.length > 0 ? medianCalculator.evaluate(neighborArray) : Double.NaN;
+                        writableRaster.setSample(x, y, band, !Double.isNaN(medianValue) ? medianValue : originalValue);
+                    } else {
+                        writableRaster.setSample(x, y, band, originalValue);
+                    }
+                }
+            }
+        }
+
+        GridCoverage2D modifiedRaster = RasterUtils.clone(writableRaster, raster.getGridGeometry(), raster.getSampleDimensions(), raster, null, true);
+        return modifiedRaster;
+    }
+
+    /**
+     * Filters out the noDataValue pixels from each band as a grid coverage
+     *
+     * @param raster
+     * @return Returns a grid coverage with noDataValues and valid data values as Double.Nan
+     */
+    public static GridCoverage2D extractNoDataValueMask(GridCoverage2D raster) {
+        Raster rasterData = raster.getRenderedImage().getData();
+        WritableRaster writableRaster = rasterData.createCompatibleWritableRaster(RasterAccessors.getWidth(raster), RasterAccessors.getHeight(raster));
+
+        // Iterate over each band
+        for (int band = 0; band < raster.getNumSampleDimensions(); band++) {
+            GridSampleDimension sampleDimension = raster.getSampleDimension(band);
+            Double noDataValue = RasterUtils.getNoDataValue(sampleDimension);
+
+            for (int y = 0; y < rasterData.getHeight(); y++) {
+                for (int x = 0; x < rasterData.getWidth(); x++) {
+                    double originalValue = rasterData.getSampleDouble(x, y, band);
+                    if (originalValue == noDataValue) {
+                        writableRaster.setSample(x, y, band, originalValue);
+                    } else {
+                        writableRaster.setSample(x, y, band, Double.NaN);
+                    }
+                }
+            }
+        }
+
+        GridCoverage2D modifiedRaster = RasterUtils.clone(writableRaster, raster.getGridGeometry(), raster.getSampleDimensions(), raster, null, true);
+        return modifiedRaster;
+    }
+
+    /**
+     * Superimposes the mask values onto the original raster, maintaining the original values where the mask is NaN.
+     *
+     * @param raster The original raster to which the mask will be applied.
+     * @param mask Grid coverage mask to be applied, containing the values to overlay. This mask should have the same dimensions and number of bands as the original raster.
+     * @return A new GridCoverage2D object with the mask applied.
+     */
+    public static GridCoverage2D applyRasterMask(GridCoverage2D raster, GridCoverage2D mask) {
+        Raster rasterData = raster.getRenderedImage().getData();
+        Raster maskData = mask.getRenderedImage().getData();
+        WritableRaster writableRaster = rasterData.createCompatibleWritableRaster(RasterAccessors.getWidth(raster), RasterAccessors.getHeight(raster));
+
+        // Iterate over each band
+        for (int band = 0; band < raster.getNumSampleDimensions(); band++) {
+            for (int y = 0; y < rasterData.getHeight(); y++) {
+                for (int x = 0; x < rasterData.getWidth(); x++) {
+                    double originalValue = rasterData.getSampleDouble(x, y, band);
+                    double maskValue = maskData.getSampleDouble(x, y, band);
+                    if (!Double.isNaN(maskValue)) {
+                        writableRaster.setSample(x, y, band, maskValue);
+                    } else {
+                        writableRaster.setSample(x, y, band, originalValue);
+                    }
+                }
+            }
+        }
+
+        GridCoverage2D modifiedRaster = RasterUtils.clone(writableRaster, raster.getGridGeometry(), raster.getSampleDimensions(), raster, null, false);
+        return modifiedRaster;
+    }
+
 }
