@@ -37,8 +37,7 @@ import java.util.Objects;
 import java.util.stream.Collectors;
 
 import static junit.framework.TestCase.assertNull;
-import static org.apache.flink.table.api.Expressions.$;
-import static org.apache.flink.table.api.Expressions.call;
+import static org.apache.flink.table.api.Expressions.*;
 import static org.junit.Assert.*;
 
 public class FunctionTest extends TestBase{
@@ -86,6 +85,18 @@ public class FunctionTest extends TestBase{
         Table bufferTable = pointTable.select(call(Functions.ST_Buffer.class.getSimpleName(), $(pointColNames[0]), 1));
         Geometry result = (Geometry) first(bufferTable).getField(0);
         assert(result instanceof Polygon);
+
+        String actual = (String) first(tableEnv.sqlQuery("SELECT ST_AsText(ST_ReducePrecision(ST_Buffer(ST_GeomFromWKT('LINESTRING(0 0, 50 70, 100 100)'), 10, 'side=left'), 4))")).getField(0);
+        String expected = "POLYGON ((50 70, 0 0, -8.1373 5.8124, 41.8627 75.8124, 43.2167 77.3476, 44.855 78.5749, 94.855 108.5749, 100 100, 50 70))";
+        assertEquals(expected, actual);
+
+        actual = (String) first(tableEnv.sqlQuery("SELECT ST_AsText(ST_ReducePrecision(ST_Buffer(ST_GeomFromWKT('LINESTRING(0 0, 50 70, 70 -3)'), 10, 'endcap=square'), 4))")).getField(0);
+        expected = "POLYGON ((43.2156 77.3465, 44.8523 78.5733, 46.7044 79.4413, 48.6944 79.9144, 50.739 79.9727, 52.7527 79.6137, 54.6512 78.8525, 56.3552 77.7209, 57.7932 76.2663, 58.9052 74.5495, 59.6446 72.6424, 79.6446 -0.3576, 82.2869 -10.0022, 62.9978 -15.2869, 45.9128 47.0733, 8.1373 -5.8124, 2.325 -13.9497, -13.9497 -2.325, 41.8627 75.8124, 43.2156 77.3465))";
+        assertEquals(expected, actual);
+
+        actual = (String) first(tableEnv.sqlQuery("SELECT ST_AsText(ST_ReducePrecision(ST_Buffer(ST_Point(100, 90), 200, 'quad_segs=4'), 4))")).getField(0);
+        expected = "POLYGON ((284.7759 13.4633, 241.4214 -51.4214, 176.5367 -94.7759, 100 -110, 23.4633 -94.7759, -41.4214 -51.4214, -84.7759 13.4633, -100 90, -84.7759 166.5367, -41.4214 231.4214, 23.4633 274.7759, 100 290, 176.5367 274.7759, 241.4214 231.4214, 284.7759 166.5367, 300 90, 284.7759 13.4633))";
+        assertEquals(expected, actual);
     }
 
     @Test
@@ -221,6 +232,12 @@ public class FunctionTest extends TestBase{
                 , "epsg:4326", "epsg:3857"));
         String result = first(transformedTable).getField(0).toString();
         assertEquals("POINT (-13134586.718698347 3764623.3541299687)", result);
+
+        pointTable = pointTable.select(call(Functions.ST_SetSRID.class.getSimpleName(), $(pointColNames[0]), 4326)).as(pointColNames[0]);
+        transformedTable = pointTable.select(call(FunctionsGeoTools.ST_Transform.class.getSimpleName(), $(pointColNames[0]), "epsg:3857"))
+                .as(pointColNames[0]).select(call(Functions.ST_ReducePrecision.class.getSimpleName(), $(pointColNames[0]), 2));
+        result = first(transformedTable).getField(0).toString();
+        assertEquals("POINT (-13134586.72 3764623.35)", result);
     }
 
     @Test
@@ -342,6 +359,14 @@ public class FunctionTest extends TestBase{
         assertEquals("POINT (1 0)", result.toString());
     }
 
+    @Test
+    public void testLineLocatePoint() {
+        Table resultTable = tableEnv.sqlQuery("SELECT ST_LineLocatePoint(ST_GeomFromWKT('LINESTRING (0 2, 1 1, 2 0)'), ST_GeomFromWKT('POINT (0 0)'))");
+        Double result = (Double) first(resultTable).getField(0);
+        Double expectedResult = 0.5;
+        assertEquals(expectedResult, result, 0.1);
+    }
+
     @Test
     public void testYMax() {
         Table polygonTable = createPolygonTable(1);
@@ -720,6 +745,23 @@ public class FunctionTest extends TestBase{
         Table polygonTable = createPolygonTable(1);
         polygonTable = polygonTable.select(call(Functions.ST_IsValid.class.getSimpleName(), $(polygonColNames[0])));
         assertTrue((boolean) first(polygonTable).getField(0));
+
+        final int OGC_SFS_VALIDITY = 0;
+        final int ESRI_VALIDITY = 1;
+
+        // Geometry that is invalid under both OGC and ESRI standards
+        String selfTouchingWKT = "POLYGON ((0 0, 2 0, 1 1, 2 2, 0 2, 1 1, 0 0))";
+        Table specialCaseTable = tableEnv.sqlQuery("SELECT ST_GeomFromText('" + selfTouchingWKT + "') AS geom");
+
+        // Test with OGC flag
+        Table ogcValidityTable = specialCaseTable.select(call("ST_IsValid", $("geom"), OGC_SFS_VALIDITY));
+        java.lang.Boolean ogcValidity = (java.lang.Boolean)first(ogcValidityTable).getField(0);
+        assertEquals(false, ogcValidity); // Expecting a self-intersection error as per OGC standards
+
+        // Test with ESRI flag
+        Table esriValidityTable = specialCaseTable.select(call("ST_IsValid", $("geom"), ESRI_VALIDITY));
+        java.lang.Boolean esriValidity = (java.lang.Boolean) first(esriValidityTable).getField(0);
+        assertEquals(false, esriValidity); // Expecting an error related to interior disconnection as per ESRI standards
     }
 
     @Test
@@ -794,6 +836,10 @@ public class FunctionTest extends TestBase{
         table = table.select(call(Functions.ST_MakeLine.class.getSimpleName(), $("point1"), $("point2")));
         Geometry result = (Geometry) first(table).getField(0);
         assertEquals("LINESTRING (0 0, 1 1)", result.toString());
+
+        table = tableEnv.sqlQuery("SELECT ST_MakeLine(ARRAY[ST_Point(2, 2), ST_Point(3, 3)]) AS line");
+        result = (Geometry) first(table).getField(0);
+        assertEquals("LINESTRING (2 2, 3 3)", result.toString());
     }
 
     @Test
@@ -1175,4 +1221,39 @@ public class FunctionTest extends TestBase{
         assertEquals(3, result, 0);
     }
 
+    @Test
+    public void testIsValidReason() {
+        // Test with an invalid geometry (bow-tie polygon)
+        String bowTieWKT = "POLYGON ((100 200, 100 100, 200 200, 200 100, 100 200))";
+        Table bowTieTable = tableEnv.sqlQuery("SELECT ST_GeomFromText('" + bowTieWKT + "') AS geom");
+        Table bowTieValidityTable = bowTieTable.select(call("ST_IsValidReason", $("geom")));
+        String bowTieValidityReason = (String) first(bowTieValidityTable).getField(0);
+        System.out.println(bowTieValidityReason);
+        assertTrue(bowTieValidityReason.contains("Self-intersection"));
+
+        // Test with a valid geometry (simple linestring)
+        String lineWKT = "LINESTRING (220227 150406, 2220227 150407, 222020 150410)";
+        Table lineTable = tableEnv.sqlQuery("SELECT ST_GeomFromText('" + lineWKT + "') AS geom");
+        Table lineValidityTable = lineTable.select(call("ST_IsValidReason", $("geom")));
+        String lineValidityReason = (String) first(lineValidityTable).getField(0);
+        assertEquals("Valid Geometry", lineValidityReason);
+
+        final int OGC_SFS_VALIDITY = 0;
+        final int ESRI_VALIDITY = 1;
+
+        // Geometry that is invalid under both OGC and ESRI standards, but with different reasons
+        String selfTouchingWKT = "POLYGON ((0 0, 2 0, 1 1, 2 2, 0 2, 1 1, 0 0))";
+        Table specialCaseTable = tableEnv.sqlQuery("SELECT ST_GeomFromText('" + selfTouchingWKT + "') AS geom");
+
+        // Test with OGC flag
+        Table ogcValidityTable = specialCaseTable.select(call("ST_IsValidReason", $("geom"), OGC_SFS_VALIDITY));
+        String ogcValidityReason = (String) first(ogcValidityTable).getField(0);
+        assertEquals("Ring Self-intersection at or near point (1.0, 1.0, NaN)", ogcValidityReason); // Expecting a self-intersection error as per OGC standards
+
+        // Test with ESRI flag
+        Table esriValidityTable = specialCaseTable.select(call("ST_IsValidReason", $("geom"), ESRI_VALIDITY));
+        String esriValidityReason = (String) first(esriValidityTable).getField(0);
+        assertEquals("Interior is disconnected at or near point (1.0, 1.0, NaN)", esriValidityReason); // Expecting an error related to interior disconnection as per ESRI standards
+    }
+
 }
