@@ -66,6 +66,8 @@ object st_functions extends DataFrameAPI {
 
   def ST_Buffer(geometry: Column, buffer: Column): Column = wrapExpression[ST_Buffer](geometry, buffer)
   def ST_Buffer(geometry: String, buffer: Double): Column = wrapExpression[ST_Buffer](geometry, buffer)
+  def ST_Buffer(geometry: Column, buffer: Column, parameters: Column): Column = wrapExpression[ST_Buffer](geometry, buffer, parameters)
+  def ST_Buffer(geometry: String, buffer: Double, parameters: String): Column = wrapExpression[ST_Buffer](geometry, buffer, parameters)
 
   def ST_BuildArea(geometry: Column): Column = wrapExpression[ST_BuildArea](geometry)
   def ST_BuildArea(geometry: String): Column = wrapExpression[ST_BuildArea](geometry)
@@ -169,6 +171,15 @@ object st_functions extends DataFrameAPI {
   def ST_IsValid(geometry: Column): Column = wrapExpression[ST_IsValid](geometry)
   def ST_IsValid(geometry: String): Column = wrapExpression[ST_IsValid](geometry)
 
+  def ST_IsValid(geometry: Column, flag: Column): Column = wrapExpression[ST_IsValid](geometry, flag)
+  def ST_IsValid(geometry: String, flag: Integer): Column = wrapExpression[ST_IsValid](geometry, flag)
+
+  def ST_IsValidReason(geometry: Column): Column = wrapExpression[ST_IsValidReason](geometry)
+  def ST_IsValidReason(geometry: String): Column = wrapExpression[ST_IsValidReason](geometry)
+
+  def ST_IsValidReason(geometry: Column, flag: Column): Column = wrapExpression[ST_IsValidReason](geometry, flag)
+  def ST_IsValidReason(geometry: String, flag: Integer): Column = wrapExpression[ST_IsValidReason](geometry, flag)
+
   def ST_Length(geometry: Column): Column = wrapExpression[ST_Length](geometry)
   def ST_Length(geometry: String): Column = wrapExpression[ST_Length](geometry)
 
@@ -178,6 +189,9 @@ object st_functions extends DataFrameAPI {
   def ST_LineInterpolatePoint(geometry: Column, fraction: Column): Column = wrapExpression[ST_LineInterpolatePoint](geometry, fraction)
   def ST_LineInterpolatePoint(geometry: String, fraction: Double): Column = wrapExpression[ST_LineInterpolatePoint](geometry, fraction)
 
+  def ST_LineLocatePoint(linestring: Column, point: Column): Column = wrapExpression[ST_LineLocatePoint](linestring, point)
+  def ST_LineLocatePoint(linestring: String, point: String): Column = wrapExpression[ST_LineLocatePoint](linestring, point)
+
   def ST_LineMerge(multiLineString: Column): Column = wrapExpression[ST_LineMerge](multiLineString)
   def ST_LineMerge(multiLineString: String): Column = wrapExpression[ST_LineMerge](multiLineString)
 
@@ -278,6 +292,8 @@ object st_functions extends DataFrameAPI {
   def ST_Transform(geometry: String, sourceCRS: String, targetCRS: String): Column = wrapExpression[ST_Transform](geometry, sourceCRS, targetCRS, false)
   def ST_Transform(geometry: Column, sourceCRS: Column, targetCRS: Column, disableError: Column): Column = wrapExpression[ST_Transform](geometry, sourceCRS, targetCRS, disableError)
   def ST_Transform(geometry: String, sourceCRS: String, targetCRS: String, disableError: Boolean): Column = wrapExpression[ST_Transform](geometry, sourceCRS, targetCRS, disableError)
+  def ST_Transform(geometry: String, targetCRS: String): Column = wrapExpression[ST_Transform](geometry, targetCRS)
+  def ST_Transform(geometry: Column, targetCRS: Column): Column = wrapExpression[ST_Transform](geometry, targetCRS)
 
   def ST_Union(a: Column, b: Column): Column = wrapExpression[ST_Union](a, b)
   def ST_Union(a: String, b: String): Column = wrapExpression[ST_Union](a, b)
@@ -425,4 +441,3 @@ object st_functions extends DataFrameAPI {
   def ST_IsCollection(geometry: String): Column = wrapExpression[ST_IsCollection](geometry)
 
 }
- 
\ No newline at end of file
